@@ -5,7 +5,7 @@ oer+MySQL - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2003 EQU <equ@equnet.org>
+Copyright (C) 2000-2004 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -97,7 +97,7 @@ extern int uptime(time_t *, time_t *);
 extern int deladmin(char *, int);
 extern int deladminmask(char *, char *);
 extern int deluser(struct channel *, char *);
-extern int delusermask(struct channel *, char *, char *);
+extern int delusermasks(struct channel *, char *, char *, int);
 extern int deltrusted(char *);
 extern int delservice(char *);
 extern int delchannel(struct channel *);
@@ -129,6 +129,7 @@ extern int delpermbans(struct channel *, char *, int);
 extern int getmmodecount(struct channel *);
 extern int gettimedcount(void);
 extern int deltopic(struct channel *, char *, int, char *, char *, char *);
+extern int cleanautheds(struct channel *, int, int);
 extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, char *, char *);
 extern struct botuser *addbotuser(char *, char *);
@@ -229,7 +230,6 @@ extern void quit(void);
 extern void parsectcp(char *, char *, int, char *);
 extern void nstats(struct channel *, char *, int, char *);
 extern void wall(struct channel *, char *, char *, char *);
-extern void cleanautheds(struct channel *, int, int);
 extern void listchanusers(void);
 extern void timed_del(struct timed *);
 extern void mmode_del(struct channel *, struct mmode *);
