@@ -5,7 +5,7 @@ oer+MySQL - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2003 EQU <equ@equnet.org>
+Copyright (C) 2000-2004 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -56,16 +56,16 @@ void establishconnection()
                         oer_debug(OER_DEBUG_FATAL, "establishconnection->gethostname() failed, exiting.\n");
                         mystate->bailout = 1;
                         return;
-                case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY:
-                        oer_debug(OER_DEBUG_ERROR, "establishconnection->gethostbyname() temporary error, retrying.\n");
+                case OER_SERVERCONNECTION_ERR_GETADDRINFO_RETRY:
+                        oer_debug(OER_DEBUG_ERROR, "establishconnection->getaddrinfo() temporary error, retrying.\n");
                         sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
                         break;
 		case OER_SERVERCONNECTION_ERR_GETSERVER_RETRY:
                         oer_debug(OER_DEBUG_ERROR, "establishconnection->getserver() temporary error, retrying.\n");
                         sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
                         break;
-                case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME:
-                        oer_debug(OER_DEBUG_FATAL, "establishconnection->gethostbyname() fatal error, exiting.\n");
+                case OER_SERVERCONNECTION_ERR_GETADDRINFO:
+                        oer_debug(OER_DEBUG_FATAL, "establishconnection->getaddrinfo() fatal error, exiting.\n");
                         mystate->bailout = 1;
                         return;
 		case OER_SERVERCONNECTION_ERR_BIND:
@@ -188,6 +188,8 @@ int serverconnection()
         struct addrinfo *aip;
         struct addrinfo hints;
         int ai_error;
+	int sourcefamily;
+	int match;
 #ifdef DEBUG
         oer_debug(OER_DEBUG_NOISE, "serverconnection()\n");
 #endif
@@ -202,6 +204,9 @@ int serverconnection()
                 oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostname() failed: %s\n", strerror(errno));
                 return OER_SERVERCONNECTION_ERR_GETHOSTNAME;
         }
+	/* assume default hostname is a IPv4 host, if a vhost is specified oer
+	   will find out the protocol family for that vhost */
+        sourcefamily = PF_INET;
         if(strlen(mystate->vhost)) {
                 /* override with virtual host */
                 strncpy(mystate->host, mystate->vhost, HOSTLEN);
@@ -212,12 +217,12 @@ int serverconnection()
 		memset(&hints, 0, sizeof(hints));
 		hints.ai_socktype = SOCK_STREAM;
 		if((ai_error = getaddrinfo(mystate->host, NULL, &hints, &res)) != 0) {
-			oer_debug(OER_DEBUG_ERROR, "serverconnection->getaddrinfo() for host %s failed: %s\n", mystate->host, gai_strerror(ai_error));
+			oer_debug(OER_DEBUG_ERROR, "serverconnection->getaddrinfo() for host %s failed: %s (%d)\n", mystate->host, gai_strerror(ai_error), ai_error);
 			if(ai_error == EAI_AGAIN) {
 				oer_debug(OER_DEBUG_ERROR, "serverconnection->getaddrinfo() non-fatal error, retrying\n");
-				return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY;
+				return OER_SERVERCONNECTION_ERR_GETADDRINFO_RETRY;
 			} else {
-				return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME;
+				return OER_SERVERCONNECTION_ERR_GETADDRINFO;
 			}
 		}
 		for(aip = res; aip != NULL; aip = aip->ai_next) {
@@ -233,10 +238,11 @@ int serverconnection()
 				return OER_SERVERCONNECTION_ERR_BIND;
 			}
 			/* we are satisfied */
+                        sourcefamily = aip->ai_family;
 			break;
 		}
+		freeaddrinfo(res);
 	}
-	freeaddrinfo(res);
 	/* get IRC server to connect to */
         if((mystate->current_server = getserver()) == NULL) {
                 /* we didn't get a server this time but we will eventually
@@ -254,15 +260,17 @@ int serverconnection()
         memset(&hints, 0, sizeof(hints));
         hints.ai_socktype = SOCK_STREAM;
 	if((ai_error = getaddrinfo(mystate->current_server->serverhost, service, &hints, &res)) != 0) {
-                oer_debug(OER_DEBUG_ERROR, "serverconnection->getaddrinfo() for host %s service %s failed: %s\n", mystate->current_server->serverhost, service, gai_strerror(ai_error));
-                if(ai_error == EAI_AGAIN) {
-                        oer_debug(OER_DEBUG_ERROR, "serverconnection->getaddrinfo() non-fatal error, retrying\n");
-                        return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY;
-                } else {
-                        return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME;
-                }
+                oer_debug(OER_DEBUG_ERROR, "serverconnection->getaddrinfo() for host %s service %s failed: %s (%d)\n", mystate->current_server->serverhost, service, gai_strerror(ai_error), ai_error);
+		/* if we fail to resolve the server address, always retry */
+		return OER_SERVERCONNECTION_ERR_GETADDRINFO_RETRY;
         }
+	match = 0;
 	for(aip = res; aip != NULL; aip = aip->ai_next) {
+		if(aip->ai_family != sourcefamily) {
+                        /* conflicting protocol family (IPv4 <-> IPv6), skip */
+                        oer_debug(OER_DEBUG_ERROR, "serverconnection->source and destination have different socket families (%d <-> %d), trying next interface/server address\n", sourcefamily, aip->ai_family);
+                        continue;
+                }
 		if(!strlen(mystate->vhost)) {
                         /* we need to create the socket because it wasn't
                            created before for bind() */
@@ -274,7 +282,7 @@ int serverconnection()
                 }
                 if(connect(mystate->sockfd, aip->ai_addr, aip->ai_addrlen) < 0) {
                         oer_debug(OER_DEBUG_ERROR, "serverconnection->connect() failed: %s (%d)\n", strerror(errno), errno);
-                        if(errno == ECONNREFUSED || errno == ETIMEDOUT || errno == ENETUNREACH || errno == EHOSTUNREACH) {
+                        if(errno == ECONNREFUSED || errno == ETIMEDOUT || errno == ENETUNREACH || errno == EHOSTUNREACH || errno == ECONNRESET) {
 #ifdef DEBUG
                                 oer_debug(OER_DEBUG_INFO, "serverconnection->connect() non-fatal error\n");
                                 oer_debug(OER_DEBUG_INFO, "serverconnection->switching to next server if available\n");
@@ -288,9 +296,13 @@ int serverconnection()
                         return OER_SERVERCONNECTION_ERR_CONNECT;
                 }
                 /* we are satisfied */
+                match = 1;
                 break;
         }
         freeaddrinfo(res);
+	if(!match) {
+                return OER_SERVERCONNECTION_ERR_SOCKET;
+        }
         proxysetup();
         mystate->current_server->connected = 1;
         mystate->current_server->rx = 0;
