@@ -5,7 +5,7 @@ oer+MySQL - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2003 EQU <equ@equnet.org>
+Copyright (C) 2000-2004 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -59,6 +59,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <sys/stat.h>
 #include <sys/socket.h>
 
+#ifdef HAVE_UNAME
+  #include <sys/utsname.h>
+#endif
+
 #ifdef TIME_WITH_SYS_TIME
   #include <sys/time.h>
   #include <time.h>
@@ -190,8 +194,8 @@ enum ESTABLISHCONNECTION_RETURN_VALUES {
 enum SERVERCONNECTION_RETURN_VALUES {
 	OER_SERVERCONNECTION_ERR_SOCKET,
 	OER_SERVERCONNECTION_ERR_GETHOSTNAME,
-	OER_SERVERCONNECTION_ERR_GETHOSTBYNAME,
-	OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY,
+	OER_SERVERCONNECTION_ERR_GETADDRINFO,
+	OER_SERVERCONNECTION_ERR_GETADDRINFO_RETRY,
 	OER_SERVERCONNECTION_ERR_GETSERVER_RETRY,
 	OER_SERVERCONNECTION_ERR_BIND,
 	OER_SERVERCONNECTION_ERR_CONNECT,
@@ -346,6 +350,7 @@ enum OER_FLAGS_TYPE {
 #define OER_BURST_JOINS_LIMIT OER_JOINS / 2
 #define OER_DELAY_BETWEEN_REJOINS 10
 #define OER_DELAY_BETWEEN_REJOINS_CYCLE 1
+#define OER_DELAY_CHANMODES_AFTER_JOIN 10
 #define OER_DELAY_BETWEEN_RECORD_CHECKS 120
 #define OER_AUTO_REJOIN_TIME 3
 #define OER_QUOTE_INTERVAL 300
@@ -372,7 +377,7 @@ enum OER_FLAGS_TYPE {
 #define OER_LOGON_TIMEOUT 1800
 #define OER_REGISTERCONNECTION_TIMEOUT 600
 #define OER_MYSQL_CONNECTION_RETRY 60
-#define OER_MYSQL_CONNECTION_RETRY_AFTER_LOSS 1800
+#define OER_MYSQL_CONNECTION_RETRY_AFTER_LOSS 600
 #define OER_MYSQL_TIMESTAMP_CHECK_INTERVAL 300
 #define OER_BANVARS_AUTO_REJOIN 30
 #define OER_BANVARS_PART_REJOIN 600
@@ -423,7 +428,7 @@ enum OER_FLAGS_TYPE {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org"
 #define OER_UNKNOWN "unknown"
-#define OER_VERSION "oer+MySQL version 1.0-41"
+#define OER_VERSION "oer+MySQL version 1.0-42"
 #define OER_COPYRIGHT1 "Copyright (C) 2000-2003 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
@@ -649,6 +654,8 @@ struct channel {
 	int allhostsknown;
         int whoquery;
 	int requestop_now;
+	int chankeyisset;
+        int chanlimitisset;
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t last_advert;
