@@ -317,7 +317,7 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
 
     readln "Please specify bot admin hostmask [equ@*.equnet.org] " "equ@*.equnet.org"
     ADMINHOSTMASK=$ans
-    INSERT_HOSTMASKS="INSERT INTO oer_hostmasks VALUES ('$ADMINHOSTMASK','',1,'$ADMIN','$HANDLE')"
+    INSERT_HOSTMASKS="INSERT INTO oer_hostmasks VALUES ('$ADMINHOSTMASK','-',1,'$ADMIN','$HANDLE')"
 
     if [ "$ISDYN" = "d" ]; then
 	INSERT_PASSWORDS="INSERT INTO oer_passwords VALUES ('$ADMIN','',2,'$CRYPT','$HANDLE')"
