@@ -15,6 +15,17 @@ CREATE TABLE oer_admins (
   PRIMARY KEY (handle,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_admins_sync'
+#
+
+CREATE TABLE oer_admins_sync (
+  handle VARCHAR(32) NOT NULL,
+  flags VARCHAR(32),
+  ident VARCHAR(20) NOT NULL,
+  PRIMARY KEY (handle,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_adverts'
 #
@@ -40,6 +51,20 @@ CREATE TABLE oer_autheds (
   PRIMARY KEY (ttype,twhen,thandle,tchannel,thostmask,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_autheds_sync'
+#
+
+CREATE TABLE oer_autheds_sync (
+  ttype VARCHAR(32) NOT NULL,
+  twhen INT UNSIGNED NOT NULL,
+  thandle VARCHAR(32) NOT NULL,
+  tchannel VARCHAR(50) NOT NULL,
+  thostmask VARCHAR(80) NOT NULL,
+  ident VARCHAR(20) NOT NULL,
+  PRIMARY KEY (ttype,twhen,thandle,tchannel,thostmask,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_bantype'
 #
@@ -147,6 +172,19 @@ CREATE TABLE oer_hostmasks (
   PRIMARY KEY (hostmask,channel,type,handle,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_hostmasks_sync'
+#
+
+CREATE TABLE oer_hostmasks_sync (
+  hostmask VARCHAR(80) NOT NULL,
+  channel VARCHAR(50) NOT NULL,
+  type TINYINT UNSIGNED NOT NULL,
+  handle VARCHAR(32) NOT NULL,
+  ident VARCHAR(20) NOT NULL,
+  PRIMARY KEY (hostmask,channel,type,handle,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_kickreasons'
 #
@@ -207,6 +245,19 @@ CREATE TABLE oer_passwords (
   PRIMARY KEY (handle,channel,type,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_passwords_sync'
+#
+
+CREATE TABLE oer_passwords_sync (
+  handle VARCHAR(32) NOT NULL,
+  channel VARCHAR(50) NOT NULL,
+  type TINYINT unsigned NOT NULL,
+  password VARCHAR(32) NOT NULL,
+  ident VARCHAR(20) NOT NULL,
+  PRIMARY KEY (handle,channel,type,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_permbans'
 #
@@ -284,6 +335,18 @@ CREATE TABLE oer_timestamps (
   PRIMARY KEY (ttype,tchannel,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_timestamps_sync'
+#
+
+CREATE TABLE oer_timestamps_sync (
+  ttype VARCHAR(32) NOT NULL,
+  twhen INT UNSIGNED NOT NULL,
+  tchannel VARCHAR(50) NOT NULL,
+  ident VARCHAR(20) NOT NULL,
+  PRIMARY KEY (ttype,tchannel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_topics'
 #
@@ -319,6 +382,18 @@ CREATE TABLE oer_users (
   PRIMARY KEY (handle,channel,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_users_sync'
+#
+
+CREATE TABLE oer_users_sync (
+  handle VARCHAR(32) NOT NULL,
+  channel VARCHAR(50) NOT NULL,
+  flags VARCHAR(32),
+  ident VARCHAR(20) NOT NULL,
+  PRIMARY KEY (handle,channel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_wordbks'
 #
