@@ -10,14 +10,15 @@
 
 $args = $#ARGV + 1;
 
-if ($args != 2) {
+if ($args != 3) {
     print "insufficient number of arguments\n";
-    print "usage: logconv.pl <type> <channel>\n";
+    print "usage: logconv.pl <type> <channel> <ident>\n";
     exit;
 }
 
 $arg1 = @ARGV[0];
 $arg2 = @ARGV[1];
+$arg3 = @ARGV[2];
 
 if($arg1 ne "last" && $arg1 ne "seen") {
     print "required argument missing.\n";
@@ -26,11 +27,16 @@ if($arg1 ne "last" && $arg1 ne "seen") {
 }
 
 $tablename = "$arg1\_$arg2";
+$tablename =~ s/\-//g;
 $tablename =~ s/\.//g;
 $tablename =~ s/\#//g;
 
 if($arg1 eq "last") {
-    print "INSERT INTO $arg1 (channel,nick,twhen,hostmask,message) SELECT '$arg2',nick,twhen,hostmask,message FROM $tablename;\n";
+    print "INSERT INTO oer_$arg1 (channel,nick,twhen,hostmask,ident,message) SELECT '$arg2',nick,twhen,hostmask,'$arg3',message FROM $tablename;\n";
 } else {
-    print "INSERT INTO $arg1 (channel,nick,twhen,hostmask) SELECT '$arg2',nick,twhen,hostmask FROM $tablename;\n";
+    print "INSERT INTO oer_$arg1 (channel,nick,twhen,hostmask,ident) SELECT '$arg2',nick,twhen,hostmask,'$arg3' FROM $tablename;\n";
 }
+
+
+
+
